@@ -16,8 +16,7 @@ from typing import List, Dict, Any, Optional
 
 from .progress import CliProgress
 from .. import VERSION_WITH_DEPS
-from ..utils.config import Config, load_projects, load_config, \
-    config_to_dict
+from ..utils.config import Config, load_config, config_to_dict
 from .cli_builder import rename, return_to_stdout, partial, lazy_partial, \
     Subcommands, Subcommand, SubcommandGroup, decorate, block, set_default
 from ..utils.log import exception_to_message, add_stream_handler_to_logger, \
@@ -146,8 +145,13 @@ class Cli(Subcommands):
                 "recipient": dict(help="fingerprint, key ID or email associated "
                                   "with GPG key of data recipient(s).",
                                   alias='-r'),
-                "project_id": dict(help="Project id", alias='-p'),
-                "offline": dict(help="Offline mode (do not validate the project_id)"),
+                "transfer_id": dict(help="Transfer id (optional)", alias='-t'),
+                "offline": dict(
+                    help="Offline mode: skip transfer_id validation and key "
+                         "refreshing."),
+                "purpose": dict(
+                    help="Purpose of the transfer (PRODUCTION, TEST), "
+                         "default: PRODUCTION"),
                 "output_name": dict(
                     help="output encrypted file name. If no path is specified, "
                          "the output tarball is saved in the current working "
@@ -206,14 +210,6 @@ class Cli(Subcommands):
                         create_config,
                         help="Commands related to config file"
                         ),
-        SubcommandGroup("info",
-                        decorate(load_projects,
-                                 rename("list-projects"),
-                                 return_to_stdout,
-                                 partial(config=config)
-                                 ),
-                        help="Output information"
-                        ),
         Subcommand(
             decorate(
                 request_sigs,
