@@ -67,10 +67,14 @@ def verify_checksums(checksums: Iterable[Tuple[str, str]],
     for checksum, file_name in checksums:
         # Open file in read-only mode and verify its checksum is the same
         # as the one given in input_file. File name should be posix, just in case it is NOT...
-        file_path = Path(base_path) / Path(file_name.replace('\\', os.path.sep))
+        file_path = Path(base_path) / \
+            Path(file_name.replace('\\', os.path.sep))
         with open(file_path, 'rb') as f:
-            if checksum != compute_checksum_sha256(f):
-                raise UserError('Checksum mismatch for: {file_name}')
+            computed = compute_checksum_sha256(f)
+            checksum = checksum.lower()
+            if checksum != computed:
+                raise UserError(f'Checksum mismatch for: {file_name}\nExpected: {checksum}'
+                                f'\nGot: {computed}')
 
 
 def read_checksum_file(f: io.IOBase) -> Iterable[Tuple[str, str]]:
