@@ -85,6 +85,12 @@ def create_revocation_certificate(fingerprint: str, passphrase: str,
     return gpg_store.gen_revoke(fingerprint, passphrase=passphrase)
 
 
+def verify_key_length(key: gpg.Key, min_key_length: int = 4096):
+    if key.key_length < min_key_length:
+        raise UserError(f"Key {key.key_id} is shorter than the minimal "
+                        f"required length of {min_key_length} bit")
+
+
 def upload_keys(fingerprints: List[str], keyserver: str,
                 gpg_store: GPGStore):
     """Upload public key to keyserver"""
@@ -92,7 +98,7 @@ def upload_keys(fingerprints: List[str], keyserver: str,
         gpg_store.send_keys(*fingerprints,
                             keyserver=keyserver, url_opener=urlopen)
     except urllib.error.URLError:
-        raise KeyserverError(action='download', keyserver=keyserver)
+        raise KeyserverError(action="upload", keyserver=keyserver)
 
 
 def download_keys(fingerprints: List[str], keyserver: str,
@@ -182,7 +188,8 @@ def retrieve_keys(gpg_store: GPGStore,
     # If asked to do so, refresh keys by re-downloading them from keyserver.
     if with_refresh_keys:
         pub_keys = refresh_keys(keys=pub_keys,
-                                gpg_store=gpg_store, sigs=True)
+                                gpg_store=gpg_store, sigs=True,
+                                keyserver_url=keyserver_url)
     # Verify keys are signed and non-revoked.
     for key in pub_keys:
         validate_pub_key(key, validation_keyid, keyserver_url)
