@@ -35,3 +35,12 @@ def socks_handler(protocol, host, port):
     return SocksiPyHandler(protocol, host, port)
 
 urlopen = build_opener()
+
+
+def post(url: str, data: bytes):
+    request = urllib.request.Request(
+        url, data, method='POST',
+        headers={"Content-Type": "application/json; charset=UTF-8"})
+    with urlopen(request) as response:
+        response_text = response.read()
+        return response_text
