@@ -4,6 +4,7 @@ from dataclasses import dataclass, field
 
 from PySide2 import QtCore
 
+from ..core.metadata import Purpose
 from ..utils.config import Config
 
 
@@ -97,8 +98,9 @@ class AppData:
 
     encrypt_sender: str = ""
     encrypt_recipients: Tuple[str] = tuple()
-    encrypt_project_id: str = ""
-    encrypt_project_id_validate: bool = True
+    encrypt_transfer_id: Optional[str] = None
+    encrypt_offline: bool = False
+    encrypt_purpose: Purpose = Purpose.PRODUCTION
     encrypt_compress: bool = True
     encrypt_output_suffix: str = ""
     encrypt_output_location: Path = field(default_factory=Path.home)
