@@ -1,8 +1,7 @@
 import os
 import platform
 import json
-from typing import List, Dict, Any, Optional
-import urllib.error
+from typing import Dict, Any, Optional
 import tempfile
 
 import dataclasses
@@ -11,10 +10,8 @@ from dataclasses import dataclass
 from libbiomedit.lib.deserialize import deserialize
 
 from .log import exception_to_message, get_default_log_dir, create_logger
-from ..core.model import Project
 from ..core.crypt import open_gpg_dir, get_default_gpg_config_dir
 from ..core.error import UserError
-from ..core.request import urlopen
 from .. import APP_NAME_SHORT
 
 
@@ -61,18 +58,13 @@ class Config:
     default_sender: Optional[str] = None
     gui_quit_confirmation: bool = True
 
-    @property
-    def dcc_portal_endpoint_url(self) -> str:
-        return self.dcc_portal_url + "/backend/projects-info"
-
     @property
     def dcc_portal_pgpkey_endpoint_url(self) -> str:
         return self.dcc_portal_url + "/backend/pgpkey/"
 
     @property
-    def projects_by_id(self):
-        projects = load_projects(self)
-        return {p.project_id: p for p in projects}  # pylint: disable=not-an-iterable
+    def dcc_portal_dpkg_endpoint_url(self) -> str:
+        return self.dcc_portal_url + "/backend/data-package/"
 
     @property
     def gpg_store(self):
@@ -137,19 +129,6 @@ def load_config_dict(path: str) -> dict:
         return {}
 
 
-def load_projects(config: Config) -> List[Project]:
-    """Fetches the list of projects from the portal"""
-    if not config.dcc_portal_endpoint_url.lower().startswith('http'):
-        raise ValueError(f"Invalid scheme: '{config.dcc_portal_endpoint_url}'")
-    try:
-        with urlopen(config.dcc_portal_endpoint_url) as response:
-            projects = json.loads(response.read().decode())
-            return [Project(**project) for project in projects]
-    except (urllib.error.URLError, json.decoder.JSONDecodeError,
-            TypeError) as e:
-        raise UserError(f"Failed to load projects. {format(e)}")
-
-
 def get_config_file() -> str:
     """user platform specific config file"""
 
