@@ -16,7 +16,7 @@ from ..core.crypt import retrieve_keys, encrypt_and_sign_file, \
     detach_sign_file, check_password
 from ..core.checksum import compute_checksum_sha256, write_checksums
 from ..core.error import UserError
-from ..core.metadata import MetaData, alnum_str, ProjectIdStr
+from ..core.metadata import MetaData, alnum_str, Purpose, verify_transfer
 from ..utils.progress import ProgressInterface, subprogress, \
     progress_file_iter, with_progress
 
@@ -25,13 +25,6 @@ logger = create_logger(__name__)
 output_name_str = alnum_str(min_length=1, max_length=50, allow_dots=True)
 
 
-def get_project(project_id, config):
-    try:
-        return config.projects_by_id[project_id]
-    except KeyError:
-        raise UserError(f"Invalid project id {project_id}")
-
-
 def path_str(directory: bool = False, writable: bool = False) -> Callable:
     """Generate a 'type definition' function that will check that a string is
     a valid path (file or directory).
@@ -75,15 +68,16 @@ def check_arg_value(arg_value: str,
 @workflow(logger, (UserError, FileNotFoundError, PermissionError))
 def encrypt(files: List[str],
             *,
-            project_id: str,
             config: Config,
             recipient: List[str],
+            transfer_id: Optional[int] = None,
             sender: Optional[str] = None,
             passphrase: Optional[str] = None,
             output_name: Optional[str] = None,
             dry_run: bool = False,
             offline: bool = False,
             compress: bool = True,
+            purpose: Purpose = Purpose.PRODUCTION,
             progress: ProgressInterface = None) -> None:
     """Compress and encrypt files and/or directories.
     """
@@ -94,10 +88,6 @@ def encrypt(files: List[str],
             raise UserError(
                 "Sender not specified but no default sender could be determined")
 
-    # Check if project is valid:
-    if not offline:
-        get_project(project_id, config)
-
     if not files:
         raise UserError("Empty file list")
 
@@ -108,8 +98,9 @@ def encrypt(files: List[str],
         # Retrieve the lowest common directory of all input files/directories.
         root_dir = os.path.commonpath(Path(x).absolute().parent.as_posix()
                                       for x in files)
-        # Verify project_id and output_name input values.
-        check_arg_value(project_id, 'project ID', ProjectIdStr)
+        if not offline and transfer_id is None:
+            raise UserError("Transfer ID is missing. Use offline mode if you "
+                            "don't require Transfer ID.")
         if output_name:
             check_arg_value(Path(output_name).name,
                             'output name', output_name_str)
@@ -141,6 +132,21 @@ def encrypt(files: List[str],
                                f'key ID: {key.key_id}'
                                for key in recipients_pub_key]))
 
+        if not offline:
+            try:
+                project_id = verify_transfer(
+                    metadata=MetaData(transfer_id=transfer_id,
+                                      sender=sender_pub_key.fingerprint,
+                                      recipients=[key.fingerprint
+                                                  for key in recipients_pub_key],
+                                      checksum="",
+                                      purpose=purpose),
+                    filename="missing",
+                    portal_endpoint_url=config.dcc_portal_dpkg_endpoint_url)
+                logger.info("Transfer '%s' is a valid for project '%s'",
+                            transfer_id, project_id)
+            except RuntimeError as e:
+                raise UserError(format(e))
     if dry_run:
         logger.info('dry run completed successfully.')
         return
@@ -226,10 +232,11 @@ def encrypt(files: List[str],
             # Create a dictionary with all the info we want to store in the .json
             # file, then pass this dictionary to json.dump that will convert it to
             # a json file. Use indent=4 to make the output file easier on the eye.
-            metadata = MetaData(projectID=project_id,
+            metadata = MetaData(transfer_id=transfer_id,
                                 sender=sender_pub_key.fingerprint,
                                 recipients=[key.fingerprint
                                             for key in recipients_pub_key],
+                                purpose=purpose,
                                 checksum=encrypted_checksum,
                                 compression_algorithm="gzip" if compress else "")
             metadata_bytes = json.dumps(
