@@ -8,7 +8,7 @@ from ..utils.progress import ProgressInterface
 from ..core.crypt import get_recipient_email, extract_pub_key_ids, \
     validated_keys_by_ids
 from ..core.archive import check_tar, extract, METADATA_FILE, DATA_FILE_ENCRYPTED
-from ..core.metadata import load_metadata
+from ..core.metadata import load_metadata, verify_transfer
 from ..core.error import UserError
 from ..protocols import needs_argument
 
@@ -49,11 +49,14 @@ def transfer(files: typing.List[str],
                     config.gpg_store,
                     config.key_validation_authority_keyid,
                     config.keyserver_url))
-            metadata = load_metadata(metadata, config.projects_by_id)
-            project_id = metadata.projectID
-            project = config.projects_by_id.get(project_id)
-            if project is None:
-                raise KeyError(f"Could not find project with id {project_id}")
+            metadata = load_metadata(metadata)
+            try:
+                project_id = verify_transfer(metadata=metadata, filename=tar,
+                    portal_endpoint_url=config.dcc_portal_dpkg_endpoint_url)
+                logger.info("Transfer '%s' is a valid for project '%s'",
+                            metadata.transfer_id, project_id)
+            except RuntimeError as e:
+                raise UserError(format(e))
             files_by_recipient.setdefault(keys, []).append(tar)
 
     if dry_run:
